@@ -869,7 +869,7 @@ def to_geqdsk(eqm, t_in=0.):
     geq['BCENTR']  = equ.B0[jt]
     geq['RCENTR']  = equ.R0  ##[jt]   # TODO this seems to be time-independent?
     geq['ZMID']    = 0.5*(equ.Zmesh[-1] + equ.Zmesh[0])
-    geq['PSIRZ']   = equ.pfm[:, :, jt].T
+    geq['PSIRZ'] = equ.pfm[:, :, jt]
 
     # Interpolate onto an equidistant Psi-grid
     psi_grid = np.linspace(psi_in[0], psi_in[-1], len(equ.Rmesh))
