@@ -4,10 +4,24 @@ import logging
 import numpy as np
 from scipy.integrate import cumtrapz
 
-from aug_sfutils import sfobj, SFREAD, parse_kwargs, cocos
+from aug_sfutils import sfobj, SFREAD, parse_kwargs
 
 logger = logging.getLogger('aug_sfutils.sf2equ')
 
+#--------------------------------
+# COCOs
+# https://crppwww.epfl.ch/~sauter/cocos/Sauter_COCOS_Tokamak_Coordinate_Conventions.pdf
+# Table I page 8
+#--------------------------------
+
+sigma = { \
+    'bp'       : [ 1,  1, -1, -1,  1,  1, -1, -1], \
+    'rphiz'    : [ 1, -1,  1, -1,  1, -1,  1, -1], \
+    'rhothephi': [ 1,  1, -1, -1, -1, -1,  1,  1]}
+
+explain = {'rphiz'    : {1: '(R, phi, Z) r'    , -1: '(R, Z, phi) l'}, \
+           'rhothephi': {1: '(rho, the, phi) r', -1: '(rho, phi, the) l'    } }
+
 
 class EQU:
     """Reads the whole equilibrium shotfile
@@ -55,8 +69,8 @@ class EQU:
             ## Actual shotfile edition (> 0)
             self.ed = self.sf.ed
 
-            ## COCOs number
-            self.cocos = 17
+            ## COCO number
+            self.coco = 17
 
             ## Time grid of equilibrium shotfile
             self.time = self.sf.getobject('time')
@@ -91,18 +105,18 @@ class EQU:
         logger.info('Reading equ PFM')
         self.read_pfm()
 
-        logger.info('COCO %d' %self.cocos)
+        logger.info('COCO %d' %self.coco)
 
-# Sign of Ip, Bt (positive=ccw from above), valid for COCOS=17 (CLISTE)
+# Sign of Ip, Bt (positive=ccw from above), valid for COCO=17 (CLISTE)
         self.ip_ccw = np.sign((self.psix - self.psi0).mean())
         self.bt_ccw = np.sign(np.nanmean(self.jpol))
 
-        jcoco = self.cocos%10 - 1
-        ebp   = self.cocos//10
-        psi_sign = -self.ip_ccw*cocos.sigma['bp'][jcoco]*cocos.sigma['rphiz'][jcoco]
+        jcoco = self.coco%10 - 1
+        ebp   = self.coco//10
+        psi_sign = -self.ip_ccw*sigma['bp'][jcoco]*sigma['rphiz'][jcoco]
         psi_2pi  = (2.*np.pi)**ebp
         self.psi_fac = psi_sign*psi_2pi
-        self.phi_sign = self.bt_ccw*cocos.sigma['rphiz'][jcoco]
+        self.phi_sign = self.bt_ccw*sigma['rphiz'][jcoco]
 
         if 'tbeg' in kwargs.keys():
             tbeg = kwargs['tbeg']
@@ -350,6 +364,88 @@ class EQU:
         return var_sorted, dvar_sorted
 
 
+    def find_coco(self, ip_shot='ccw', bt_shot='cw'):
+        """
+        Identifies the COCO number of a given equilibrium object
+        """
+
+# dpsi_sign positive if psi_sep > psi0
+        dpsi_sign = np.sign(np.mean(self.psix) - np.mean(self.psi0))
+# Known plasma discharge
+        ccw_ip = 1 if(ip_shot == 'ccw') else -1 # AUG default: 1
+        ccw_bt = 1 if(bt_shot == 'ccw') else -1 # AUG default: -1
+
+# Table III
+
+        sign_q  = np.sign(np.nanmean(self.q))
+        sign_ip = np.sign(np.nanmean(self.ipipsi))
+        sign_bt = np.sign(np.nanmean(self.jpol))
+        sigma_rphiz = sign_ip*ccw_ip
+        sigma_bp    = dpsi_sign*sign_ip
+# Eq 45
+        sigma_rhothephi = sign_q*sign_ip*sign_bt
+        logger.debug(sigma_bp, sigma_rphiz, sigma_rhothephi)
+        for jc, rhothephi in enumerate(sigma['rhothephi']):
+            if(sigma['bp'   ][jc] == sigma_bp    and \
+               sigma['rphiz'][jc] == sigma_rphiz and \
+               rhothephi          == sigma_rhothephi):
+                self.coco = jc + 1
+                break
+
+# Find out 2*pi factor for Psi
+
+        dphi = np.gradient(self.tfl, axis=1)
+        dpsi = np.gradient(self.pfl, axis=1)
+
+# Radial+time average
+# It is either q_ratio ~ 1 (COCO > 10) or ~ 2*pi (COCO < 10)
+        q_ratio = np.abs(np.nanmean(dphi/(self.q*dpsi)))
+        logger.debug('Ratio %8.4f' %q_ratio)
+        if q_ratio < 4:
+            self.coco += 10
+
+
+    def to_coco(self, coco_out=11):
+        """
+        Transforms equilibrium object into any wished output COCO
+        """
+
+# Assuming SI
+
+        coco_in = self.coco
+        logger.info('COCO conversion from %d to %d' %(coco_in, coco_out))
+        jc_in   = coco_in %10 - 1
+        jc_out  = coco_out%10 - 1
+        ebp_in  = coco_in//10
+        ebp_out = coco_out//10
+#    sign_ip_in = np.sign(np.nanmean(self.ipipsi))
+# Equation 9, table I, equation 39, 45
+        q_sign   = sigma['rhothephi'][jc_in]*sigma['rhothephi'][jc_out]
+        phi_sign = sigma['rphiz'][jc_in]*sigma['rphiz'][jc_out]
+        psi_sign = sigma['rphiz'][jc_in]*sigma['bp'][jc_in] * sigma['rphiz'][jc_out]*sigma['bp'][jc_out]
+        psi_2pi  = (2.*np.pi)**(ebp_out - ebp_in)
+        psi_fac = psi_sign*psi_2pi
+        try:
+            logger.debug(np.mean(self.jav), phi_sign)
+        except:
+            pass
+
+        for key, val in self.__dict__.items():
+            if val is None:
+                continue
+            if key in ('B0', 'jpol', 'jav', 'tfl', 'ip', 'ipipsi', 'phi_sign'):
+                self.__dict__[key] = val*phi_sign
+            elif key in ('psi0', 'psix', 'pfl', 'pfm', 'psi_fac'):
+                self.__dict__[key] = val*psi_fac
+            elif key in ('dpres', 'darea', 'dvol', 'ffp'):
+                self.__dict__[key] = val/psi_fac
+            elif key in ('djpol', ):
+                self.__dict__[key] = val*phi_sign/psi_fac
+            elif key in ('q', 'q0', 'q25', 'q50', 'q75', 'q95'):
+                self.__dict__[key] = val*q_sign
+        self.coco = coco_out
+
+
 if __name__ == '__main__':
 
 
