@@ -46,6 +46,10 @@ fmt2descr[12034] = 'CHAR48'
 fmt2descr[16130] = 'CHAR64'
 fmt2descr[18178] = 'CHAR72'
 
+descr2fmt = {}
+for key, val in fmt2descr.items():
+    descr2fmt[val] = key
+
 # /usr/ads/codes
 #  objects
 obj_name = {1 : 'Diagnostic', 2: 'List', 3: 'Device', 4: 'ParamSet', \
@@ -53,6 +57,11 @@ obj_name = {1 : 'Diagnostic', 2: 'List', 3: 'Device', 4: 'ParamSet', \
             9 : 'SFList', 10: 'Algorithm', 11: 'UpdateSet', \
             12: 'LocTimer', 13: 'AreaBase', 14: 'Qualifier', \
             15: 'ModObj', 16: 'MapExtd', 17: 'Resource', 18: 'ADDRLEN'}
+
+objnam2num = {}
+for key, val in obj_name.items():
+    objnam2num[val] = key
+
 #  calibration
 cal_type = {0: 'NoCalib', 1: 'LinCalib', 2: 'LookUpTab', 3: 'extCalib'}
 
