@@ -107,13 +107,23 @@ class SFREAD:
 
         if 'sfh' in kwargs.keys():
             self.sfile = kwargs['sfh']
-        if 'sf' in kwargs.keys():
-            self.sfile = kwargs['sf']
-        if hasattr(self, 'sfile'):
             self.shot = 0
             self.ed = 0
             self.diag = os.path.basename(self.sfile)[:3]
 
+        elif 'sf' in kwargs.keys():
+            self.sfile = os.path.abspath(kwargs['sf'])
+            dirs = self.sfile.split('/')[::-1]
+            sshot = ''
+            for subdir in dirs:
+                try:
+                    a = float(subdir)
+                    sshot = subdir + sshot
+                except:
+                    self.diag = subdir
+                    break
+            self.shot = int(sshot.split('.')[0])
+
         else:
 
             n_args = len(args) 
