@@ -7,7 +7,7 @@ from aug_sfutils import sfdics, str_byt
 
 logger = logging.getLogger('aug_sfutils.ww')
 logger.setLevel(logging.INFO)
-#logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.DEBUG)
 
 
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
@@ -324,20 +324,20 @@ class WW:
                 logger.error('AB %s hat %d dims: only a time and a space dependence are allowed, flatten the space data', areaname, data.ndim)
                 return
 
-            if sizes is not None:
-                nx = len(sizes)
-                csizes[:nx] = sizes[:nx]
-
             if tim_axis is None:
                 nt = 1
-                if sizes is None:
-                    csizes[0] = data.shape[0]
+                data = np.atleast_2d(data).T
             else:
                 if tim_axis == 0:
                     data = data.T
                 nt = data.shape[1]
-                if sizes is None:
-                    csizes[0] = data.shape[0]
+
+            if sizes is None:
+                csizes[0] = data.shape[0]
+            else:
+                nx = len(sizes)
+                csizes[:nx] = sizes[:nx]
+
 
             logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *csizes)
 
@@ -475,7 +475,11 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
 
     for obj, data in data_d.items():
         if otype[obj] == AreaBase:
-            ww.SetObject(obj, data, tim_axis=0)
+            if data.ndim == 1:
+                tim_ax = None
+            else:
+                tim_ax = 0
+            ww.SetObject(obj, data, tim_axis=tim_ax)
 
     for obj, data in data_d.items():
         if otype[obj] == ParamSet:
